%define common_summary interact with virtualization capabilities
%define common_description Libvirt is a C toolkit to interact with the virtualization\
capabilities of recent versions of Linux.
%define lib_major 0

%define lib_name %mklibname virt %{lib_major}
%define develname %mklibname -d virt
%define staticdevelname %mklibname -d -s virt

# libxenstore is not versionned properly
%define __noautoreq 'devel(libxenstore.*)'

Name:       libvirt
Version:    0.9.13
Release:    3
Summary:    Toolkit to %{common_summary}
License:    LGPLv2+
Group:      System/Kernel and hardware
Url:        http://libvirt.org/
Source0:     http://libvirt.org/sources/%{name}-%{version}.tar.gz
Patch0:		libvirt-0.9.7-undefined_fix.diff
# XXX: for %%{_sysconfdir}/sasl2
Requires:   cyrus-sasl
%ifarch %{ix86} x86_64
BuildRequires:  xen-devel >= 3.0.4
%endif
BuildRequires:  libxml2-devel
BuildRequires:  ncurses-devel
BuildRequires:  readline-devel
BuildRequires:  python-devel
BuildRequires:  gnutls-devel
BuildRequires:  libsasl-devel
BuildRequires:  libpciaccess-devel
BuildRequires:  polkit-1-devel polkit
BuildRequires:  parted-devel
BuildRequires:  open-iscsi
BuildRequires:  lvm2
BuildRequires:  yajl-devel
BuildRequires:  dmsetup
BuildRequires:  libxml2-utils
BuildRequires:  nfs-utils
BuildRequires:  libavahi-client-devel
BuildRequires:  xmlrpc-c-devel
%if %{mdkversion} >= 201000
BuildRequires:  numa-devel
%endif
BuildRequires:  qemu
BuildRequires:  gettext-devel
BuildRequires:  libnl-devel
BuildRequires:  libpcap-devel
BuildRequires:  systemtap
BuildRequires:  autoconf automake libtool
%if %{mdkversion} >= 201010
BuildRequires:	netcf-devel
%endif

%description
%{common_description}

Virtualization of the Linux Operating System means the
ability to run multiple instances of Operating Systems concurently on
a single hardware system where the basic resources are driven by a
Linux instance. The library aim at providing long term stable C API
initially for the Xen paravirtualization but should be able to
integrate other virtualization mechanisms if needed.

%package -n %{lib_name}
Summary:    A library to %{common_summary}
Group:      System/Libraries

%description -n %{lib_name}
%{common_description}

This package contains the library needed to run programs dynamically
linked with %{name}.

%package -n %{develname}
Summary:    Development tools for programs using %{name}
Group:      Development/C
Requires:   %{lib_name} = %{version}
%ifarch %{ix86} x86_64
Requires:   xen-devel
%endif
Provides:   %{name}-devel = %{version}-%{release}
Obsoletes:  %{lib_name}-devel

%description -n %{develname}
%{common_description}

This package contains the header files and libraries needed for
developing programs using the %{name} library.

%package -n %{staticdevelname}
Summary:    Development static libraries for programs using %{name}
Group:      Development/C
Provides:   %{name}-static-devel = %{version}-%{release}
Obsoletes:  %{lib_name}-static-devel

%description -n %{staticdevelname}
%{common_description}

This package contains the static libraries needed for developing
programs using the %{name} library.

%package -n python-%{name}
Summary:    Python bindings to %{common_summary}
Group:      Development/Python

%description -n python-%{name}
%{common_description}

This package contains the python bindings for the %{name} library.

%package -n %{name}-utils
Summary:    Tools to %{common_summary}
Group:      System/Kernel and hardware
Requires:   bridge-utils
Requires:   %{lib_name} = %{version}
%if %{mdkversion} >= 201000
Requires:   polkit
%else
Requires:   policykit
%endif
Suggests:   dnsmasq-base
Suggests:   netcat-openbsd
Conflicts:  libvirt0 < 0.7.1-2
Conflicts:  lib64virt0 < 0.7.1-2

%description -n %{name}-utils
%{common_description}

This package contains tools for the %{name} library.

%prep
%setup -q
%patch0 -p0

%build
autoreconf -fi
%configure2_5x \
    --localstatedir=%{_var}  \
    --with-html-subdir=%{name} \
    --with-udev \
    --without-hal
%make

%install
%makeinstall_std
install -d -m 755 %{buildroot}%{_var}/run/%{name}
install -d -m 755 %{buildroot}%{_var}/lib/%{name}
%find_lang %{name}

# fix documentation
mv %{buildroot}%{_docdir}/%{name}-python-%{version} %{buildroot}%{_docdir}/python-%{name}
install -m 644 ChangeLog README TODO NEWS %{buildroot}%{_docdir}/%{name}

rm -f %{buildroot}%{_libdir}/*.la
rm -f %{buildroot}%{py_platsitedir}/*.la
rm -f %{buildroot}%{_libdir}/libvirt/connection-driver/*.a

%check
# fhimpe: disabled for now because it fails on 100Hz kernels, such as used on bs
# http://www.mail-archive.com/libvir-list@redhat.com/msg13727.html
#make check

%files -n %{lib_name}
%{_libdir}/%{name}.so.%{lib_major}*
%{_libdir}/%{name}-qemu.so.%{lib_major}*
%{_libdir}/libvirt_lxc

%files -n %{develname}
%{_docdir}/%{name}
%exclude %{_docdir}/%{name}/ChangeLog
%exclude %{_docdir}/%{name}/README
%exclude %{_docdir}/%{name}/TODO
%exclude %{_docdir}/%{name}/NEWS
%doc %{_datadir}/gtk-doc/html/%{name}
%{_includedir}/%{name}
%{_libdir}/%{name}.so
%{_libdir}/%{name}-qemu.so
%{_libdir}/pkgconfig/%{name}.pc

%files -n %{staticdevelname}
%{_libdir}/%{name}.a
%{_libdir}/%{name}-qemu.a

%files -n python-%{name}
%doc %{_docdir}/python-%{name}
%{py_platsitedir}/%{name}.py
%{py_platsitedir}/%{name}mod.so

%files -n %{name}-utils -f %{name}.lang
%dir %{_docdir}/%{name}
%{_docdir}/%{name}/ChangeLog
%{_docdir}/%{name}/README
%{_docdir}/%{name}/TODO
%{_docdir}/%{name}/NEWS
%{_bindir}/*
%{_mandir}/man1/virsh.1*
%{_mandir}/man1/virt-xml-validate.1*
%{_mandir}/man1/virt-pki-validate.1.*
%{_mandir}/man8/libvirtd.8.*
%{_mandir}/man1/virt-host-validate.1.*
%{_sbindir}/*
%{_initrddir}/libvirtd
%dir %attr(0700, root, root) %{_localstatedir}/log/libvirt/qemu/
%dir %attr(0700, root, root) %{_localstatedir}/log/libvirt/lxc/
%dir %attr(0700, root, root) %{_localstatedir}/log/libvirt/uml/
%{_libdir}/libvirt_iohelper
%{_libdir}/libvirt_parthelper
%{_libdir}/libvirt/connection-driver/libvirt_driver_interface.so
%{_libdir}/libvirt/connection-driver/libvirt_driver_libxl.so
%{_libdir}/libvirt/connection-driver/libvirt_driver_lxc.so
%{_libdir}/libvirt/connection-driver/libvirt_driver_network.so
%{_libdir}/libvirt/connection-driver/libvirt_driver_nodedev.so
%{_libdir}/libvirt/connection-driver/libvirt_driver_nwfilter.so
%{_libdir}/libvirt/connection-driver/libvirt_driver_qemu.so
%{_libdir}/libvirt/connection-driver/libvirt_driver_secret.so
%{_libdir}/libvirt/connection-driver/libvirt_driver_storage.so
%{_libdir}/libvirt/connection-driver/libvirt_driver_uml.so
%{_libdir}/libvirt/connection-driver/libvirt_driver_xen.so
%{_var}/run/libvirt
%{_var}/lib/libvirt
%{_datadir}/polkit-1/actions/org.libvirt.unix.policy
%{_datadir}/augeas
%{_datadir}/%{name}
%{_datadir}/systemtap/tapset/libvirt_functions.stp
%{_datadir}/systemtap/tapset/libvirt_probes.stp
%{_datadir}/systemtap/tapset/libvirt_qemu_probes.stp

%config(noreplace) %{_sysconfdir}/libvirt
%config(noreplace) %{_sysconfdir}/sasl2/libvirt.conf
%config(noreplace) %{_sysconfdir}/sysconfig/libvirtd
%config(noreplace) %{_sysconfdir}/sysconfig/libvirt-guests
%config(noreplace) %{_sysconfdir}/logrotate.d/libvirtd*
%config(noreplace) %{_sysconfdir}/sysctl.d/libvirtd
%{_initrddir}/libvirt-guests
%{py_platsitedir}/libvirt_qemu.py
%{py_platsitedir}/libvirtmod_qemu.so


%changelog
* Mon Jul 09 2012 Bogdano Arendartchuk <bogdano@mandriva.com> 0.9.13-3
+ Revision: 808612
- added unpackaged connection drivers
- rebuild to use libyajl (required by qemu)

  + Alexander Khrukin <akhrukin@mandriva.org>
    - rel up
    - version update 0.9.13

* Mon May 14 2012 Bernhard Rosenkraenzer <bero@bero.eu> 0.9.12-1
+ Revision: 798768
- Update to 0.9.12
- Fix build in current environment

* Fri May 04 2012 Alexander Khrukin <akhrukin@mandriva.org> 0.9.11-2
+ Revision: 795782
- rel bump and rebuild

* Mon Apr 23 2012 Alexander Khrukin <akhrukin@mandriva.org> 0.9.11-1
+ Revision: 792772
- version update 0.9.11

* Thu Feb 16 2012 Per Øyvind Karlsen <peroyvind@mandriva.org> 0.9.9-1
+ Revision: 775166
- add missing build dependency on polkit
- new version

  + Bogdano Arendartchuk <bogdano@mandriva.com>
    - changed buildreq for polkit-1-devel
    - moved the lxc helper tool to the main library

* Mon Nov 28 2011 Oden Eriksson <oeriksson@mandriva.com> 0.9.7-1
+ Revision: 735117
- fix deps
- fix build
- 0.9.7
- drop *.la files
- use the python rpm macros (duh!)
- relink against new pcap

  + Sergey Zhemoitel <serg@mandriva.org>
    - new release 0.9.6

* Mon Jul 18 2011 Guillaume Rousse <guillomovitch@mandriva.org> 0.9.3-1
+ Revision: 690546
- new version

* Mon Jun 20 2011 Oden Eriksson <oeriksson@mandriva.com> 0.9.2-2
+ Revision: 686318
- avoid pulling 32 bit libraries on 64 bit arch

* Wed Jun 15 2011 Guillaume Rousse <guillomovitch@mandriva.org> 0.9.2-1
+ Revision: 685267
- update to new version 0.9.2

* Mon May 30 2011 Funda Wang <fwang@mandriva.org> 0.9.1-2
+ Revision: 681972
- rebuild for new parted

* Wed May 11 2011 Guillaume Rousse <guillomovitch@mandriva.org> 0.9.1-1
+ Revision: 673624
- new version

* Mon Apr 18 2011 Guillaume Rousse <guillomovitch@mandriva.org> 0.9.0-1
+ Revision: 655777
- new version

* Fri Mar 25 2011 Buchan Milne <bgmilne@mandriva.org> 0.8.8-3
+ Revision: 648511
- Buildrequire netcf-devel, for network interface configuration from libvirt (virsh/virt-manager)
- Add a patch to fix qemu 0.14 boot arguments

* Wed Mar 16 2011 Matthew Dawkins <mattydaw@mandriva.org> 0.8.8-2
+ Revision: 645654
- added missing BR libpciaccess-devel
- disabled hal and enabled udev

* Sun Feb 20 2011 Guillaume Rousse <guillomovitch@mandriva.org> 0.8.8-1
+ Revision: 639039
- update to new version 0.8.8

* Sat Jan 08 2011 Guillaume Rousse <guillomovitch@mandriva.org> 0.8.7-1mdv2011.0
+ Revision: 630674
- update to new version 0.8.7

* Thu Dec 02 2010 Guillaume Rousse <guillomovitch@mandriva.org> 0.8.6-1mdv2011.0
+ Revision: 604694
- new version

* Thu Nov 11 2010 Guillaume Rousse <guillomovitch@mandriva.org> 0.8.5-1mdv2011.0
+ Revision: 596117
- new version
- fix build (gentoo patch)

* Fri Nov 05 2010 Götz Waschk <waschk@mandriva.org> 0.8.4-2mdv2011.0
+ Revision: 593738
- rebuild for new python 2.7

* Wed Sep 15 2010 Guillaume Rousse <guillomovitch@mandriva.org> 0.8.4-1mdv2011.0
+ Revision: 578760
- update to new version 0.8.4

* Sat Aug 07 2010 Guillaume Rousse <guillomovitch@mandriva.org> 0.8.3-1mdv2011.0
+ Revision: 567285
- new version

* Thu Jul 15 2010 Guillaume Rousse <guillomovitch@mandriva.org> 0.8.2-1mdv2011.0
+ Revision: 553811
- new version

* Tue May 18 2010 Guillaume Rousse <guillomovitch@mandriva.org> 0.8.0-2mdv2010.1
+ Revision: 545263
- fix configuration files list (#59341)

* Wed Apr 14 2010 Guillaume Rousse <guillomovitch@mandriva.org> 0.8.0-1mdv2010.1
+ Revision: 534687
- new version

* Wed Mar 10 2010 Sandro Cazzaniga <kharec@mandriva.org> 0.7.7-1mdv2010.1
+ Revision: 517286
- update to libvirt 0.7.7

* Sat Feb 27 2010 Funda Wang <fwang@mandriva.org> 0.7.6-2mdv2010.1
+ Revision: 512201
- rebuild for new parted

* Thu Feb 04 2010 Guillaume Rousse <guillomovitch@mandriva.org> 0.7.6-1mdv2010.1
+ Revision: 500665
- new version

* Tue Jan 26 2010 Frederic Crozat <fcrozat@mandriva.com> 0.7.5-2mdv2010.1
+ Revision: 496767
- Fix backport for subpackages

* Sun Dec 27 2009 Frederik Himpe <fhimpe@mandriva.org> 0.7.5-1mdv2010.1
+ Revision: 482729
- update to new version 0.7.5

* Sun Dec 27 2009 Funda Wang <fwang@mandriva.org> 0.7.4-3mdv2010.1
+ Revision: 482620
- rebuild for new parted

* Sun Dec 06 2009 Guillaume Rousse <guillomovitch@mandriva.org> 0.7.4-2mdv2010.1
+ Revision: 474269
- add nfs-utils and xmlrpc-c-devel build dependencies
- don't build xenproxy, it's not useful anymore
- no explicit openvz switch, it's automatically enabled

* Wed Dec 02 2009 Funda Wang <fwang@mandriva.org> 0.7.4-1mdv2010.1
+ Revision: 472618
- New version 0.7.4

* Sat Nov 07 2009 Frederik Himpe <fhimpe@mandriva.org> 0.7.2-1mdv2010.1
+ Revision: 462073
- Update to new version 0.7.2
- Sync patches with Fedora

* Wed Oct 07 2009 Frederik Himpe <fhimpe@mandriva.org> 0.7.1-5mdv2010.0
+ Revision: 455681
- Fix patches with Fedora

* Sun Sep 27 2009 Olivier Blin <blino@mandriva.org> 0.7.1-4mdv2010.0
+ Revision: 450013
- fix build on non x86 arches by not enabling xen-proxy, not sure it's
  a lot usefull as qemu on mips is not there (yet. remains a bunch of
  work to do) and qemu on arm is probably broken (from Arnaud Patard)

* Fri Sep 18 2009 Frederic Crozat <fcrozat@mandriva.com> 0.7.1-3mdv2010.0
+ Revision: 444395
- Allow package to be backported on old distributions

* Thu Sep 17 2009 Frederik Himpe <fhimpe@mandriva.org> 0.7.1-2mdv2010.0
+ Revision: 444131
- Fix libification

* Tue Sep 15 2009 Frederik Himpe <fhimpe@mandriva.org> 0.7.1-1mdv2010.0
+ Revision: 443144
- Update to new version 0.7.1
- Remove obsolete patches

* Wed Aug 26 2009 Frederik Himpe <fhimpe@mandriva.org> 0.7.0-4mdv2010.0
+ Revision: 421544
- Should not depend on GUI package polkit-agent. From Fedora's SPEC, it seems
  polkit is enough

* Wed Aug 26 2009 Frederik Himpe <fhimpe@mandriva.org> 0.7.0-3mdv2010.0
+ Revision: 421532
- Add Fedora patches (build with polkit-1 now)

* Wed Aug 19 2009 Guillaume Rousse <guillomovitch@mandriva.org> 0.7.0-2mdv2010.0
+ Revision: 418302
- upstream patch for LXC driver crash (fix #52809)

* Sat Aug 08 2009 Frederik Himpe <fhimpe@mandriva.org> 0.7.0-1mdv2010.0
+ Revision: 411753
- Update to new version 0.7.0

* Mon Jul 27 2009 Emmanuel Andry <eandry@mandriva.org> 0.6.5-2mdv2010.0
+ Revision: 400623
- rebuild for new parted

* Sat Jul 04 2009 Frederik Himpe <fhimpe@mandriva.org> 0.6.5-1mdv2010.0
+ Revision: 392367
- update to new version 0.6.5

* Tue Jun 09 2009 Frederik Himpe <fhimpe@mandriva.org> 0.6.4-1mdv2010.0
+ Revision: 384566
- Remove shared-readonly-label Fedora patch: related to selinux, so
  it's of no use in Mandriva, and Fedora dropped it too now
- Disable test suite for now because it fails with 100HZ kernels
  such as used on build system
- Only enable numa support on 2010.0 and higher

  + Eugeni Dodonov <eugeni@mandriva.com>
    - Updated to 0.6.4.
      Cleaned up no longer needed patches.

* Thu May 21 2009 Frederik Himpe <fhimpe@mandriva.org> 0.6.3-6mdv2010.0
+ Revision: 378339
- Add two patches from Debian:
  * Declare support for QEMU migration in capabilities
  * Don't crash with def == NULL when calling libvirt_lxc without arguments
- Add patches from Fedora:
  * Fix readonly/shared disk image labelling (RH bug #493692)
  * Fix handling of <hostdev managed='yes'> (RH bug #499386)
  * Refresh qemu caps when getCapabilities is called (RH bug #460649)
  * Enable migration with qemu 0.10
  * Don't try to label a disk with no path (e.g. empty cdrom) (RH bug #499569)

  + Guillaume Rousse <guillomovitch@mandriva.org>
    - add numactl support

* Tue May 19 2009 Frederik Himpe <fhimpe@mandriva.org> 0.6.3-4mdv2010.0
+ Revision: 377802
- Add upstream patch fixing kvm --help parsing with kvm 85
- Change init script LSB patch to start after hal and avahi

* Sun May 17 2009 Funda Wang <fwang@mandriva.org> 0.6.3-3mdv2010.0
+ Revision: 376542
- use correct flags

* Wed May 06 2009 Guillaume Rousse <guillomovitch@mandriva.org> 0.6.3-2mdv2010.0
+ Revision: 372460
- add additional openvz, qemu and avahi support

* Sat May 02 2009 Frederik Himpe <fhimpe@mandriva.org> 0.6.3-1mdv2010.0
+ Revision: 370630
- Update to new version 0.6.3
- Remove patches integrated upstream
- Add patch fixing build with -Werror=format-security

* Fri Apr 10 2009 Frederik Himpe <fhimpe@mandriva.org> 0.6.1-3mdv2009.1
+ Revision: 365915
- Don't restart libvirtd when resuming from hibernation, it breaks
  the pipe if virt-manager is left running and does not fix the
  IPv4 forwarding disabled problem after resume anyway

* Fri Mar 27 2009 Frederik Himpe <fhimpe@mandriva.org> 0.6.1-2mdv2009.1
+ Revision: 361522
- libvirtd uses messagebus, so change the init script so that it is
  started later than messagebus
- Add upstream bugfix patches from Fedora
- Restart libvirtd on resume after suspension, otherwise IP forwarding
  is not re-enabled after resume

* Thu Mar 05 2009 Frederik Himpe <fhimpe@mandriva.org> 0.6.1-1mdv2009.1
+ Revision: 349138
- BuildRequires libxml2-utils for xmllint, used by test suite
- Update to new version 0.6.1
- Patch init script to include LSB headers to start network and
  name resolution before libvirt, otherwise libvirt stops working
  if it's started too early
- Run test suite

* Wed Feb 25 2009 Guillaume Rousse <guillomovitch@mandriva.org> 0.6.0-2mdv2009.1
+ Revision: 344754
- rebuild against new readline

* Thu Feb 05 2009 Guillaume Rousse <guillomovitch@mandriva.org> 0.6.0-1mdv2009.1
+ Revision: 337832
- new version

* Mon Jan 19 2009 Guillaume Rousse <guillomovitch@mandriva.org> 0.5.1-3mdv2009.1
+ Revision: 331457
- utils package suggests netcat-openbsd (fix #46465)
- utils package should require same version of the lib
- no tabs, only spaces in spec file

* Fri Jan 02 2009 Funda Wang <fwang@mandriva.org> 0.5.1-2mdv2009.1
+ Revision: 323417
- rebuild

* Mon Dec 08 2008 Guillaume Rousse <guillomovitch@mandriva.org> 0.5.1-1mdv2009.1
+ Revision: 311991
- new version

* Tue Dec 02 2008 Guillaume Rousse <guillomovitch@mandriva.org> 0.5.0-1mdv2009.1
+ Revision: 309482
- new version
- disable as_needed, it breaks HAL detection

* Mon Oct 27 2008 Frederik Himpe <fhimpe@mandriva.org> 0.4.6-3mdv2009.1
+ Revision: 297746
- Suggest dnsmasq-base: libvirt uses this package to provide DHCP and
  DNS services to virtual machines with NAT networking
- Create /var/lib/libvirt, where the dnsmasq leases file will be
  stored

* Tue Oct 14 2008 Frederik Himpe <fhimpe@mandriva.org> 0.4.6-2mdv2009.1
+ Revision: 293754
- Make libvirt-utils require bridge-utils, otherwise virsh fails to
  activate the virbr0 bridge

* Mon Oct 13 2008 Guillaume Rousse <guillomovitch@mandriva.org> 0.4.6-1mdv2009.1
+ Revision: 293116
- new version

* Thu Aug 14 2008 Guillaume Rousse <guillomovitch@mandriva.org> 0.4.4-2mdv2009.0
+ Revision: 272027
- make devel package requires xen-devel

* Tue Jul 01 2008 Guillaume Rousse <guillomovitch@mandriva.org> 0.4.4-1mdv2009.0
+ Revision: 230502
- update file list and build dependencies

  + Emmanuel Andry <eandry@mandriva.org>
    - New version

  + Pixel <pixel@mandriva.com>
    - do not call ldconfig in %%post/%%postun, it is now handled by filetriggers

* Wed Apr 16 2008 Guillaume Rousse <guillomovitch@mandriva.org> 0.4.2-1mdv2009.0
+ Revision: 194590
- new version

  + Thierry Vignaud <tv@mandriva.org>
    - fix no-buildroot-tag

* Mon Jan 21 2008 Funda Wang <fwang@mandriva.org> 0.4.0-3mdv2008.1
+ Revision: 155530
- rebuild

* Tue Dec 18 2007 David Walluck <walluck@mandriva.org> 0.4.0-2mdv2008.1
+ Revision: 132143
- BuildRequires: libsasl-devel
- 0.4.0

  + Thierry Vignaud <tv@mandriva.org>
    - kill re-definition of %%buildroot on Pixel's request

* Fri Dec 07 2007 Guillaume Rousse <guillomovitch@mandriva.org> 0.3.3-1mdv2008.1
+ Revision: 116159
- new version

* Sat Sep 22 2007 Guillaume Rousse <guillomovitch@mandriva.org> 0.3.2-2mdv2008.0
+ Revision: 92284
- new doc policy
- ship %%{_var}/run/libvirt directory for libvirtd
- fix nasty redefinition of standard GNU directory localstatedir by %%configure macro...

* Thu Aug 30 2007 Funda Wang <fwang@mandriva.org> 0.3.2-1mdv2008.0
+ Revision: 75151
- New version 0.3.2

* Thu Jul 12 2007 Funda Wang <fwang@mandriva.org> 0.3.0-1mdv2008.0
+ Revision: 51565
- fix file list
- New version

* Tue Jun 19 2007 Guillaume Rousse <guillomovitch@mandriva.org> 0.2.3-1mdv2008.0
+ Revision: 41371
- new version

* Sat Jun 02 2007 Guillaume Rousse <guillomovitch@mandriva.org> 0.2.2-1mdv2008.0
+ Revision: 34672
- new version


* Fri Feb 23 2007 Guillaume Rousse <guillomovitch@mandriva.org> 0.2.0-1mdv2007.0
+ Revision: 125026
- fix build dependencies
- new version
- new version

* Wed Jan 17 2007 Guillaume Rousse <guillomovitch@mandriva.org> 0.1.10-1mdv2007.1
+ Revision: 109906
- minor spec cleanup
- new version

* Wed Dec 13 2006 Guillaume Rousse <guillomovitch@mandriva.org> 0.1.9-1mdv2007.1
+ Revision: 96226
- new version
- rebuild for latest python

* Mon Oct 16 2006 Olivier Blin <oblin@mandriva.com> 0.1.7-3mdv2006.0
+ Revision: 65351
- remove libxenstore devel requires on x86_64 as well

* Sun Oct 15 2006 Olivier Blin <oblin@mandriva.com> 0.1.7-2mdv2007.1
+ Revision: 65070
- don't require devel(libxenstore), it is not versionned properly

* Sat Oct 14 2006 Olivier Blin <oblin@mandriva.com> 0.1.7-1mdv2006.0
+ Revision: 64654
- buildrequires python-devel
- buildrequires readline-devel
- buildrequires ncurses-devel
- buildrequires libxml2-devel
- buildrequires libxml-devel
- initial libvirt release
- Create libvirt

